GenericErrorContext class

A context object that provides information about a generic error that occurred for a mvvm component.

This context is used by the ConfigMVVM.onGenericError callback to handle generic errors in a centralized way.

Constructors

GenericErrorContext({required ViewStatusError error, required ViewContext viewContext, required void emitViewStatus(ViewStatus viewStatus)})

Properties

emitViewStatus → void Function(ViewStatus viewStatus)
A callback function that emits a new ViewStatus.
final
error ViewStatusError
The error that occured.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewContext ViewContext
The BuildContext associated with the current view.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited