ViewStatusSuccess class

Concrete status representing a successful state.

Inheritance
Available extensions

Constructors

ViewStatusSuccess()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isFailure bool

Available on ViewStatus, provided by the ViewStatusExtension extension

Returns true if the view status is failure.
no setter
isInitial bool

Available on ViewStatus, provided by the ViewStatusExtension extension

Returns true if the view status is initial.
no setter
isLoading bool

Available on ViewStatus, provided by the ViewStatusExtension extension

Returns true if the view status is loading.
no setter
isSuccess bool

Available on ViewStatus, provided by the ViewStatusExtension extension

Returns true if the view status is successful.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited